<template>
  <div class="page-content corporate-customers">
    <transition-group tag="div" :name="transitionName" appear class="transition-group">
      <!--   表格页面   -->
      <table-page
        v-show="componentName === 'TablePage'"
        @changePage="changePage"
        :componentName="componentName"
        key="TablePage"
      />
      <!--   详情页面   -->
      <detail-page
        v-show="componentName === 'DetailPage'"
        @changePage="changePage"
        :componentName="componentName"
        key="DetailPage"
      />
    </transition-group>
  </div>
</template>

<script>
import TablePage from './components/TablePage/index.vue'
import DetailPage from './components/DetailPage/index.vue'
import PubSub from 'pubsub-js'


export default {
  name: 'AlongRouteInfo',
  components: {TablePage, DetailPage},
  data() {
    return {
      componentName: 'TablePage',
      pubSub: null,
      transitionName: ''
    }
  },
  mounted() {
    // 添加自定义面包屑pub-sub
    this.pubSub = PubSub.subscribe('breadcrumb-click', (_, item) => {
      if (item.isCurrentRoute) this.componentName = 'TablePage'
    })
  },
  methods: {
    // pageName显示页面标识符 done回调函数，保证页面挂载后执行的逻辑
    /**
     * @param {String} pageName 显示页面标识符(必传)
     * @param {Function} done 回调函数(非必传)
     * @param {String} type 面包屑标题(非必传)
     * */
    changePage(pageName = '', done, type = '') {
      this.componentName = pageName
      this.transitionName = this.transitionName === 'fold-right' ? 'fold-left' : 'fold-right'
      done && done()
      switch (pageName) {
        case 'TablePage':
          PubSub.publish('go-back')
          break
        case 'DetailPage':
          PubSub.publish('add-custom-breadcrumb', '详情')
          break
      }
    }

  },
  beforeDestroy() {
    // 在组件销毁之前 清除订阅消息
    PubSub.unsubscribe(this.pubSub)
  }
}
</script>

<style lang="scss" scoped>
</style>
